pub enum Model {
Sonnet,
Opus,
Haiku,
Haiku45,
Sonnet46,
Opus46,
Sonnet46_1M,
Opus46_1M,
}Expand description
Available Claude models.
Each variant maps to a model name passed to the Claude CLI.
Use the alias variants (Sonnet, Opus, Haiku) for the latest version,
or the explicit variants for a specific model ID and context window.
Variants
Sonnet
Claude Sonnet - balanced speed and capability (default, 200K context).
Opus
Claude Opus - highest capability (200K context).
Haiku
Claude Haiku - fastest and cheapest (200K context).
Haiku45
Claude Haiku 4.5 - 200K context.
Sonnet46
Claude Sonnet 4.6 - 200K context.
Opus46
Claude Opus 4.6 - 200K context.
Sonnet46_1M
Claude Sonnet 4.6 with 1M token context window.
Opus46_1M
Claude Opus 4.6 with 1M token context window.
Implementations