Model

Struct Model 

pub struct Model;
Provider-agnostic model identifiers.

Constants are provided for well-known Claude models, but any string is accepted - custom AgentProvider implementations interpret the model identifier however they wish.

Examples

use ironflow_core::prelude::*;

let provider = ClaudeCodeProvider::new();

// Using a built-in constant
let r = Agent::new()
    .prompt("hi")
    .model(Model::SONNET)
    .run(&provider)
    .await?;

// Using a custom model string
let r = Agent::new()
    .prompt("hi")
    .model("mistral-large-latest")
    .run(&provider)
    .await?;

Implementations

Source

impl Model

pub const SONNET: &str = "sonnet"

Claude Sonnet - balanced speed and capability (default).

pub const OPUS: &str = "opus"

Claude Opus - highest capability.

pub const HAIKU: &str = "haiku"

Claude Haiku - fastest and cheapest.

pub const HAIKU_45: &str = "claude-haiku-4-5-20251001"

Claude Haiku 4.5.

pub const SONNET_46: &str = "claude-sonnet-4-6"

Claude Sonnet 4.6.

pub const OPUS_46: &str = "claude-opus-4-6"

Claude Opus 4.6.

pub const SONNET_46_1M: &str = "claude-sonnet-4-6[1m]"

Claude Sonnet 4.6 with 1M token context window.

pub const OPUS_46_1M: &str = "claude-opus-4-6[1m]"

Claude Opus 4.6 with 1M token context window.